from ttgtcanvas2 import WorldModel, Maze
import random

def init(world):
    r = random.randint(3,10)
    c = random.randint(3,10)
    world.set_dimensions(r,c)
    
    for x in range(2,c):
        for y in range(2, r):
            world.add_tile(x, y, 'water')
    
    for x in range(1,c + 1):
        world.add_tile(x, 1, 'grass')
        world.add_tile(x, r, 'grass')

    for y in range(1,r + 1):
        world.add_tile(1, y, 'grass')
        world.add_tile(c, y, 'grass')
    
    for y in range(2,r):
        world.add_wall(1, y, "east")
        world.add_wall(c - 1, y, "east")

    for x in range(2,c):
        world.add_wall(x, 1, "north")
        world.add_wall(x, r -1, "north")
     
    world.add_wall(1, 1, "north")
    world.add_object(1,2,"carrot", 1)
        

    

def generate_maze():
    world =  WorldModel('./worlds/one.json', init)
    return Maze(world)


from ttgtcanvas2 import WorldModel, Maze
import random

def choose_fruit():
    choice = random.randint(1,3)
    if choice == 1:
        return 'apple'
    elif choice == 2:
        return 'banana'
    else:
        return 'strawberry'


def init(world):
    cfruit = 0
    world.set_quota(1000)
    #Fruit to pick
    fruit = choose_fruit()
    world.add_object(3,1, fruit, 1)
    for x in range(3, 9):
        for y in range(3,9):
            f = choose_fruit()
            world.add_object(x,y, f, 1)
            if f == fruit:
                cfruit +=1

    world.add_repoter_goal("I counted {} {}".format(cfruit, fruit))
    





def generate_maze():
    world =  WorldModel('./worlds/test.json', init)
    return Maze(world)


from ttgtcanvas2 import WorldModel, Maze
import random

def init(world):
    nb_carrot = 0
    for x in range(2, 9):
        choice = random.randint(1,2)
        if choice == 1:
            world.add_object(x, 1, "carrot", 1)
            nb_carrot += 1
   
    
    world.add_repoter_goal("I counted {} carrots".format(nb_carrot))


def generate_maze():
    world =  WorldModel('./worlds/test.json', init)
    return Maze(world)


from ttgtcanvas2 import WorldModel, Maze
import random

def init(world):
    flip = random.randint(0,1)
    left=4; right=10; bottom=3; top=7
    
    tx1 = random.randint(left  + 1 ,right - 1)
    tx2 = random.randint(left + 1,right -1)
    ry1 = random.randint(bottom + 1,top - 1)
    
    world.remove_wall(tx1, top, "north")
    world.add_goal_wall(tx1, top, "north")
    
    world.remove_wall(tx2, bottom, "south")
    world.add_goal_wall(tx2, bottom, "south")
    
    world.remove_wall(right, ry1, "east")
    world.add_goal_wall(right, ry1, "east")
    

def generate_maze():
    world =  WorldModel('./worlds/two.json', init)
    return Maze(world)


from ttgtcanvas2 import WorldModel, Maze
import random

def init(world):
    nb_carrot = 0
    nb_daisy = 0
    h = 6
    w = 6

    for x in range(2, w + 1):
        choice = random.randint(1,3)
        if choice == 1:
            world.add_object(x, 1, "carrot", 1)
            nb_carrot += 1
        elif choice == 2:
            world.add_object(x, 1,"daisy", 1)
            nb_daisy += 1
    
    for y in range(2, h + 1):
        choice = random.randint(1,3)
        if choice == 1:
            world.add_object(w, y, "carrot", 1)
            nb_carrot += 1
        elif choice == 2:
            world.add_object(w, y,"daisy", 1)
            nb_daisy += 1

    for x in range(w - 1, 1, -1):
        choice = random.randint(1,3)
        if choice == 1:
            world.add_object(x, h, "carrot", 1)
            nb_carrot += 1
        elif choice == 2:
            world.add_object(x, h,"daisy", 1)
            nb_daisy += 1
    
    for y in range(h - 1, 2, -1):
        choice = random.randint(1,3)
        if choice == 1:
            world.add_object(1, y, "carrot", 1)
            nb_carrot += 1
        elif choice == 2:
            world.add_object(1, y, "daisy", 1)
            nb_daisy += 1
    
    world.add_repoter_goal("I counted {} carrots".format(nb_carrot))


def generate_maze():
    world =  WorldModel('./worlds/three.json', init)
    return Maze(world)